DefaultTranslationContext

Enum DefaultTranslationContext 

#[non_exhaustive]
pub enum DefaultTranslationContext { ComponentName, None, }
Argument of Compiler::set_default_translation_context()

This enum specifies the default translation context when no context is explicitly specified in the @tr("context" => ...) macro.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ComponentName

The default translation context is the component name in which the @tr is written.

This is the default behavior of slint-tr-extractor.



None

Opt out of the default translation context.

When using this option, invoke slint-tr-extractor with --no-default-translation-context to make sure that the translation files have no context for strings which didn’t specify a context.