#[non_exhaustive]#[repr(u8)]pub enum SetRenderingNotifierError {
Unsupported = 0,
AlreadySet = 1,
}Expand description
This enum describes the different error scenarios that may occur when the application
registers a rendering notifier on a slint::Window.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unsupported = 0
The rendering backend does not support rendering notifiers.
AlreadySet = 1
There is already a rendering notifier set, multiple notifiers are not supported.