slint_interpreter_component_definition_global_functions

Function slint_interpreter_component_definition_global_functions 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn slint_interpreter_component_definition_global_functions( def: &ComponentDefinitionOpaque, global_name: Slice<'_, u8>, names: &mut SharedVector<SharedString>, ) -> bool
Available on crate feature ffi only.
Returns a vector of the names of the functions of the specified publicly exported global singleton. Returns true if a global exists under the specified name; false otherwise.