slint_interpreter_component_instance_create

Function slint_interpreter_component_instance_create 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn slint_interpreter_component_instance_create( def: &ComponentDefinitionOpaque, out: *mut ComponentInstance, )
Available on crate feature ffi only.
Instantiate an instance from a definition.

The out must be uninitialized and is going to be initialized after the call and need to be destroyed with slint_interpreter_component_instance_destructor