#[unsafe(no_mangle)]pub unsafe extern "C" fn slint_interpreter_struct_new(
val: *mut StructOpaque,
)Available on crate feature
ffi only.Expand description
Construct a new Struct in the given memory location
#[unsafe(no_mangle)]pub unsafe extern "C" fn slint_interpreter_struct_new(
val: *mut StructOpaque,
)ffi only.Construct a new Struct in the given memory location