#[unsafe(no_mangle)]pub extern "C" fn slint_interpreter_value_new_struct(
struc: &StructOpaque,
) -> Box<Value>Available on crate feature
ffi only.Expand description
Construct a new Value in the given memory location as Struct
#[unsafe(no_mangle)]pub extern "C" fn slint_interpreter_value_new_struct(
struc: &StructOpaque,
) -> Box<Value>ffi only.Construct a new Value in the given memory location as Struct