#[unsafe(no_mangle)]pub extern "C" fn slint_interpreter_value_to_array(
val: &Box<Value>,
out: &mut SharedVector<Box<Value>>,
) -> boolAvailable on crate feature
ffi only.Expand description
Extracts a SharedVector<ValueOpaque> out of the given value val, writes that into the
out parameter and returns true; returns false if the value does not hold an extractable
array.