slint_interpreter_value_to_model

Function slint_interpreter_value_to_model 

#[unsafe(no_mangle)]
pub extern "C" fn slint_interpreter_value_to_model( val: &Value, vtable: &ModelAdaptorVTable, ) -> *const u8
Available on crate feature ffi only.
If the value contains a model set from [slint_interpreter_value_new_model] with the same vtable pointer, return the model that was set. Returns a null ptr otherwise