pub struct Diagnostic { /* private fields */ }Available on crate feature
ffi only.Expand description
Diagnostic describes the aspects of either a warning or an error, along with its location and a description. Diagnostics are typically returned by slint::interpreter::ComponentCompiler::diagnostics() in a vector.