pub struct PropertyDescriptor { /* private fields */ }Available on crate feature
ffi only.Expand description
PropertyDescriptor is a simple structure that’s used to describe a property declared in .slint code. It is returned from in a vector from slint::interpreter::ComponentDefinition::properties().