pub struct CompilationResultSend { /* private fields */ }Expand description
A CompilationResult that can be sent to another thread.
A CompilationResult is not Send: it shares its compilation unit between
its components with an Rc. Convert one with
CompilationResult::into_send(), move it to the thread that will
instantiate the components, and convert it back with From. That way a
component can be compiled on a worker thread and instantiated on the thread
running the event loop.
let source = "export component App inherits Window { out property <int> v: 42; }".into();
let sent = std::thread::spawn(move || {
let compiler = slint_interpreter::Compiler::default();
spin_on::spin_on(compiler.build_from_source(source, Default::default())).into_send()
})
.join()
.unwrap();
let result = slint_interpreter::CompilationResult::from(sent);
let instance = result.component("App").unwrap().create().unwrap();Implementations
Sourceimpl CompilationResultSend
impl CompilationResultSend
Sourcepub fn has_errors(&self) -> bool
pub fn has_errors(&self) -> bool
Returns true if the compilation failed.
Sourcepub fn diagnostics(&self) -> impl Iterator<Item = Diagnostic> + '_
pub fn diagnostics(&self) -> impl Iterator<Item = Diagnostic> + '_
The diagnostics (errors and warnings) the compilation produced.
Sourcepub fn print_diagnostics(&self)
Available on crate feature display-diagnostics only.
pub fn print_diagnostics(&self)
display-diagnostics only.Print the diagnostics to stderr, in the same style as rustc errors.