pub fn send_key_combo(comp: &ComponentInstance, keys: &[SharedString])Expand description
Simulate pressing a combination of keys together, then releasing them in reverse order.
Each entry in keys is a key text (a single character or a special-key unicode codepoint).
All keys are pressed in order, then released in reverse